pub enum GateError {
Phase1InitError,
Phase2InitError,
MleNotFullyBoundError,
EmptyMleList,
EvaluateBoundIndicesDontMatch,
}Expand description
Error handling for gate mle construction.
Variants
Phase1InitError
Error when initializing the first phase, which is when we bind the “x” bits.
Phase2InitError
Error when initializing the second phase, which is when we bind the “y” bits.
MleNotFullyBoundError
We are on the last round of sumcheck and want to grab claims, but the MLE is not fully bound which should not be the case for the last round of sumcheck.
EmptyMleList
We are initializing a gate on something that does not have either a left or right side of the expression.
EvaluateBoundIndicesDontMatch
When checking the last round of sumcheck, the challenges don’t match what is bound to the MLE.