compute_fully_bound_identity_gate_function

Function compute_fully_bound_identity_gate_function 

pub(crate) fn compute_fully_bound_identity_gate_function<F: Field>(
    nondataparallel_round_challenges: &[F],
    nondataparallel_claim_challenges_vec: &[&[F]],
    wiring: &[(u32, u32)],
    random_coefficients: &[F],
) -> F
Compute the fully bound identity gate function, which is f_1(g, u) where the output gate label variables are fully bound to the claim on the layer and the input gate label variables are fully bound to the round challenges from sumcheck.

Similar to fold_wiring_into_beta_mle_identity_gate, this function utilizes an inspiration of Rothblum’s memory-efficient sumcheck trick in order to compute the relevant beta values over the sparse wiring function by just multiplying by the relevant inverses.

The function is also usable if parallelism is turned on, by having the folding accumulator keep track of the previous state.