compute_sumcheck_message_data_parallel_gate

Function compute_sumcheck_message_data_parallel_gate 

pub fn compute_sumcheck_message_data_parallel_gate<F: Field>(
    f2_p2_x: &DenseMle<F>,
    f3_p2_y: &DenseMle<F>,
    operation: BinaryOperation,
    wiring: &[(u32, u32, u32)],
    num_dataparallel_vars: usize,
    challenges_vec: &[&[F]],
    random_coefficients: &[F],
) -> Result<Vec<F>>
Compute the sumcheck message for a binary gate specified by the BinaryOperation.

We use a “Rothblum”-inspired sumcheck trick in order to stream the beta MLE while folding it into the wiring. We use the random coefficients to compute the RLC of all the beta values.