pub(crate) fn compute_sumcheck_message_data_parallel_identity_gate<F: Field>(
source_mle: &DenseMle<F>,
wiring: &[(u32, u32)],
num_dataparallel_vars: usize,
challenges_vec: &[&[F]],
random_coefficients: &[F],
) -> Result<Vec<F>>Expand description
Get the evals for a binary gate specified by the BinaryOperation. Note that
this specifically refers to computing the prover message while binding the
dataparallel bits of a IdentityGate expression.